@@ -130,7 +130,7 @@ class Databricks(object):
 
         try:
             response = requests.get(uri, headers = self.__header, json = body)
-            runUri = json.loads(response)["run_page_url"]
+            runUri = json.loads(response.content)["run_page_url"]
             return runUri
         except Exception as ex:
             raise ex
