@@ -11,6 +11,14 @@ class Spark(object):
     
     #endregion
 
+    #region Properties
+
+    @property
+    def Session(self):
+        return self.__sparkSession
+
+    #endregion
+
     #region Static Methods
 
     @staticmethod
