@@ -85,7 +85,7 @@ class FactTestCase(unittest.TestCase):
 
         event = TestEvent(Utilities.get_function_caller_name())
 
-        eventCode1 = "dimension-keys"
+        eventCode1 = "dimension-keys-col-categories"
         eventCode2 = "degenerate-attributes"
         eventCode3 = "fact-columns"
         eventCode4 = "bad-columns"
